Function create_owning_memo
pub fn create_owning_memo<T>(
fun: impl Fn(Option<T>) -> (T, bool) + Send + Sync + 'static,
) -> Memo<T>👎Deprecated:
This function is being removed to conform to Rust idioms. Please use Memo::new_owning() instead.
Creates a new memo by passing a function that computes the value.