create_trigger

Function create_trigger 

pub fn create_trigger() -> ArcTrigger
👎Deprecated:

This function is being removed to conform to Rust idioms. Please use ArcTrigger::new() instead.

A trigger is a data-less signal with the sole purpose of notifying other reactive code of a change.