get_config_from_env

Function get_config_from_env 

pub fn get_config_from_env() -> Result<ConfFile, LeptosConfigError>
Loads LeptosOptions from environment variables or rely on the defaults.

Errors

This function will return an error if it failed to load or parse a relevant environment variable.