Function get_config_from_file
pub fn get_config_from_file<P>(path: P) -> Result<ConfFile, LeptosConfigError>Expand description
Loads LeptosOptions from a Cargo.toml with layered overrides.
Leptos will read in the settings itself.
This option currently does not allow dashes in file or folder names, as all dashes become underscores.
Errors
This function will return an error if either:
- path was not found, or other I/O error has occurred;
get_config_from_strreturned an error.