Function hydrate_islands
pub fn hydrate_islands()Available on crate feature
hydrate only.Expand description
Hydrates any islands that are currently present on the page.
pub fn hydrate_islands()hydrate only.Hydrates any islands that are currently present on the page.