Struct AnimationFrameRequestHandle
pub struct AnimationFrameRequestHandle(i32);Expand description
Handle that is generated by request_animation_frame_with_handle and can be used to cancel the animation frame request.
Tuple Fields
0: i32Implementations
impl AnimationFrameRequestHandle
impl AnimationFrameRequestHandle
pub fn cancel(&self)
pub fn cancel(&self)
Cancels the animation frame request to which this refers.
See cancelAnimationFrame()