Struct LocalResource
pub struct LocalResource<T> {
data: AsyncDerived<T>,
refetch: RwSignal<usize>,
}Expand description
A resource that only loads its data locally on the client.
Fields
data: AsyncDerived<T>refetch: RwSignal<usize>Implementations
impl<T> LocalResource<T>
impl<T> LocalResource<T>
pub fn new<Fut>(fetcher: impl Fn() -> Fut + 'static) -> LocalResource<T>where
T: 'static,
Fut: Future<Output = T> + 'static,
pub fn new<Fut>(fetcher: impl Fn() -> Fut + 'static) -> LocalResource<T>where
T: 'static,
Fut: Future<Output = T> + 'static,
Creates the resource.
This will only begin loading data if you are on the client (i.e., if you do not have the
ssr feature activated).
pub fn refetch(&self)
pub fn refetch(&self)
Re-runs the async function.
impl<T, E> LocalResource<Result<T, E>>where
T: 'static,
E: Clone + 'static,
impl<T, E> LocalResource<Result<T, E>>where
T: 'static,
E: Clone + 'static,
pub fn and_then<U>(&self, f: impl FnOnce(&T) -> U) -> Option<Result<U, E>>
pub fn and_then<U>(&self, f: impl FnOnce(&T) -> U) -> Option<Result<U, E>>
Applies the given function when a resource that returns Result<T, E>
has resolved and loaded an Ok(_), rather than requiring nested .map()
calls over the Option<Result<_, _>> returned by the resource.
This is useful when used with features like server functions, in conjunction
with <ErrorBoundary/> and <Suspense/>, when these other components are
left to handle the None and Err(_) states.
Methods from Deref<Target = AsyncDerived<T>>
pub fn ready(&self) -> AsyncDerivedReadyFuture ⓘ
pub fn ready(&self) -> AsyncDerivedReadyFuture ⓘ
Returns a Future that is ready when this resource has next finished loading.
pub fn by_ref(&self) -> AsyncDerivedRefFuture<T> ⓘ
pub fn by_ref(&self) -> AsyncDerivedRefFuture<T> ⓘ
Returns a Future that resolves when the computation is finished, and accesses the inner
value by reference rather than by cloning it.