Struct ReadSignal
pub struct ReadSignal<T, S = SyncStorage> {
pub(crate) inner: ArenaItem<ArcReadSignal<T>, S>,
}Expand description
An arena-allocated getter for a reactive signal.
A signal is a piece of data that may change over time, and notifies other code when it has changed.
This is an arena-allocated signal, which is Copy and is disposed when its reactive
Owner cleans up. For a reference-counted signal that lives
as long as a reference to it is alive, see ArcReadSignal.
Core Trait Implementations
.get()clones the current value of the signal. If you call it within an effect, it will cause that effect to subscribe to the signal, and to re-run whenever the value of the signal changes..get_untracked()clones the value of the signal without reactively tracking it.
.read()returns a guard that allows accessing the value of the signal by reference. If you call it within an effect, it will cause that effect to subscribe to the signal, and to re-run whenever the value of the signal changes..read_untracked()gives access to the current value of the signal without reactively tracking it.
.with()allows you to reactively access the signalโs value without cloning by applying a callback function..with_untracked()allows you to access the signalโs value by applying a callback function without reactively tracking it.
.to_stream()converts the signal to anasyncstream of values.::from_stream()converts anasyncstream of values into a signal containing the latest value.
Examples
let (count, set_count) = signal(0);
// calling .get() clones and returns the value
assert_eq!(count.get(), 0);
// calling .read() accesses the value by reference
assert_eq!(count.read(), 0);Fields
inner: ArenaItem<ArcReadSignal<T>, S>Trait Implementations
impl<V, S> AddAnyAttr for ReadSignal<V, S>
impl<V, S> AddAnyAttr for ReadSignal<V, S>
type Output<SomeNewAttr: Attribute> = ReadSignal<V, S>
type Output<SomeNewAttr: Attribute> = ReadSignal<V, S>
The new type once the attribute has been added.
fn add_any_attr<NewAttr>(
self,
_attr: NewAttr,
) -> <ReadSignal<V, S> as AddAnyAttr>::Output<NewAttr>where
NewAttr: Attribute,
fn add_any_attr<NewAttr>(
self,
_attr: NewAttr,
) -> <ReadSignal<V, S> as AddAnyAttr>::Output<NewAttr>where
NewAttr: Attribute,
Adds an attribute to the view.
impl<V, S> AttributeValue for ReadSignal<V, S>
impl<V, S> AttributeValue for ReadSignal<V, S>
type AsyncOutput = ReadSignal<V, S>
type AsyncOutput = ReadSignal<V, S>
The type once all async data have loaded.
type State = RenderEffect<<V as AttributeValue>::State>
type State = RenderEffect<<V as AttributeValue>::State>
The state that should be retained between building and rebuilding.
type Cloneable = ReadSignal<V, S>
type Cloneable = ReadSignal<V, S>
A version of the value that can be cloned. This can be the same type, or a
reference-counted type. Generally speaking, this does not need to refer to the same data,
but should behave in the same way. So for example, making an event handler cloneable should
probably make it reference-counted (so that a
FnMut() continues mutating the same
closure), but making a String cloneable does not necessarily need to make it an
Arc<str>, as two different clones of a String will still have the same value.type CloneableOwned = ReadSignal<V, S>
type CloneableOwned = ReadSignal<V, S>
A cloneable type that is also
'static. This is used for spreading across types when the
spreadable attribute needs to be owned. In some cases (&'a str to Arc<str>, etc.) the owned
cloneable type has worse performance than the cloneable type, so they are separate.fn to_template(_key: &str, _buf: &mut String)
fn to_template(_key: &str, _buf: &mut String)
Renders the attribute value to HTML for a
<template>.fn hydrate<const FROM_SERVER: bool>(
self,
key: &str,
el: &Element,
) -> <ReadSignal<V, S> as AttributeValue>::State
fn hydrate<const FROM_SERVER: bool>( self, key: &str, el: &Element, ) -> <ReadSignal<V, S> as AttributeValue>::State
Adds interactivity as necessary, given DOM nodes that were created from HTML that has
either been rendered on the server, or cloned for a
<template>.fn build(
self,
el: &Element,
key: &str,
) -> <ReadSignal<V, S> as AttributeValue>::State
fn build( self, el: &Element, key: &str, ) -> <ReadSignal<V, S> as AttributeValue>::State
Adds this attribute to the element during client-side rendering.
fn rebuild(
self,
key: &str,
state: &mut <ReadSignal<V, S> as AttributeValue>::State,
)
fn rebuild( self, key: &str, state: &mut <ReadSignal<V, S> as AttributeValue>::State, )
Applies a new value for the attribute.
fn into_cloneable(self) -> <ReadSignal<V, S> as AttributeValue>::Cloneable
fn into_cloneable(self) -> <ReadSignal<V, S> as AttributeValue>::Cloneable
Converts this attribute into an equivalent that can be cloned.
fn into_cloneable_owned(
self,
) -> <ReadSignal<V, S> as AttributeValue>::CloneableOwned
fn into_cloneable_owned( self, ) -> <ReadSignal<V, S> as AttributeValue>::CloneableOwned
Converts this attributes into an equivalent that can be cloned and is
'static.fn dry_resolve(&mut self)
fn dry_resolve(&mut self)
โRunsโ the attribute without other side effects. For primitive types, this is a no-op. For
reactive types, this can be used to gather data about reactivity or about asynchronous data
that needs to be loaded.
async fn resolve(self) -> <ReadSignal<V, S> as AttributeValue>::AsyncOutput
async fn resolve(self) -> <ReadSignal<V, S> as AttributeValue>::AsyncOutput
โResolvesโ this into a form that is not waiting for any asynchronous data.
impl<T, S> Clone for ReadSignal<T, S>
impl<T, S> Clone for ReadSignal<T, S>
fn clone(&self) -> ReadSignal<T, S>
fn clone(&self) -> ReadSignal<T, S>
Returns a duplicate of the value. Read more
1.0.0 ยท Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl<T, S> Debug for ReadSignal<T, S>where
S: Debug,
impl<T, S> Debug for ReadSignal<T, S>where
S: Debug,
impl<T, S> DefinedAt for ReadSignal<T, S>
impl<T, S> DefinedAt for ReadSignal<T, S>
fn defined_at(&self) -> Option<&'static Location<'static>>
fn defined_at(&self) -> Option<&'static Location<'static>>
Returns the location at which the signal was defined. This is usually simply
None in
release mode.impl<T> From<ArcReadSignal<T>> for ReadSignal<T>
impl<T> From<ArcReadSignal<T>> for ReadSignal<T>
fn from(value: ArcReadSignal<T>) -> ReadSignal<T>
fn from(value: ArcReadSignal<T>) -> ReadSignal<T>
Converts to this type from the input type.
impl<T> From<ReadSignal<Option<T>>> for MaybeProp<T>
impl<T> From<ReadSignal<Option<T>>> for MaybeProp<T>
fn from(value: ReadSignal<Option<T>>) -> MaybeProp<T>
fn from(value: ReadSignal<Option<T>>) -> MaybeProp<T>
Converts to this type from the input type.
impl<T> From<ReadSignal<Option<T>, LocalStorage>> for MaybeProp<T, LocalStorage>
impl<T> From<ReadSignal<Option<T>, LocalStorage>> for MaybeProp<T, LocalStorage>
fn from(
value: ReadSignal<Option<T>, LocalStorage>,
) -> MaybeProp<T, LocalStorage>
fn from( value: ReadSignal<Option<T>, LocalStorage>, ) -> MaybeProp<T, LocalStorage>
Converts to this type from the input type.
impl<T> From<ReadSignal<T>> for MaybeProp<T>
impl<T> From<ReadSignal<T>> for MaybeProp<T>
fn from(value: ReadSignal<T>) -> MaybeProp<T>
fn from(value: ReadSignal<T>) -> MaybeProp<T>
Converts to this type from the input type.
impl<T> From<ReadSignal<T>> for MaybeSignal<T>
impl<T> From<ReadSignal<T>> for MaybeSignal<T>
fn from(value: ReadSignal<T>) -> MaybeSignal<T>
fn from(value: ReadSignal<T>) -> MaybeSignal<T>
Converts to this type from the input type.
impl<T> From<ReadSignal<T>> for OptionalProp<Signal<T>>
impl<T> From<ReadSignal<T>> for OptionalProp<Signal<T>>
fn from(value: ReadSignal<T>) -> OptionalProp<Signal<T>>
fn from(value: ReadSignal<T>) -> OptionalProp<Signal<T>>
Converts to this type from the input type.
impl<T> From<ReadSignal<T>> for Signal<T>
impl<T> From<ReadSignal<T>> for Signal<T>
fn from(value: ReadSignal<T>) -> Signal<T>
fn from(value: ReadSignal<T>) -> Signal<T>
Converts to this type from the input type.
impl<T> From<ReadSignal<T, LocalStorage>> for MaybeProp<T, LocalStorage>
impl<T> From<ReadSignal<T, LocalStorage>> for MaybeProp<T, LocalStorage>
fn from(value: ReadSignal<T, LocalStorage>) -> MaybeProp<T, LocalStorage>
fn from(value: ReadSignal<T, LocalStorage>) -> MaybeProp<T, LocalStorage>
Converts to this type from the input type.
impl<T> From<ReadSignal<T, LocalStorage>> for MaybeSignal<T, LocalStorage>
impl<T> From<ReadSignal<T, LocalStorage>> for MaybeSignal<T, LocalStorage>
fn from(value: ReadSignal<T, LocalStorage>) -> MaybeSignal<T, LocalStorage>
fn from(value: ReadSignal<T, LocalStorage>) -> MaybeSignal<T, LocalStorage>
Converts to this type from the input type.
impl<T> From<ReadSignal<T, LocalStorage>> for Signal<T, LocalStorage>where
T: 'static,
impl<T> From<ReadSignal<T, LocalStorage>> for Signal<T, LocalStorage>where
T: 'static,
fn from(value: ReadSignal<T, LocalStorage>) -> Signal<T, LocalStorage>
fn from(value: ReadSignal<T, LocalStorage>) -> Signal<T, LocalStorage>
Converts to this type from the input type.
impl<T, S> From<ReadSignal<T, S>> for ArcReadSignal<T>where
T: 'static,
S: Storage<ArcReadSignal<T>>,
impl<T, S> From<ReadSignal<T, S>> for ArcReadSignal<T>where
T: 'static,
S: Storage<ArcReadSignal<T>>,
fn from(value: ReadSignal<T, S>) -> ArcReadSignal<T>
fn from(value: ReadSignal<T, S>) -> ArcReadSignal<T>
Converts to this type from the input type.
impl<T, S> From<ReadSignal<T, S>> for ArcSignal<T, S>
impl<T, S> From<ReadSignal<T, S>> for ArcSignal<T, S>
fn from(value: ReadSignal<T, S>) -> ArcSignal<T, S>
fn from(value: ReadSignal<T, S>) -> ArcSignal<T, S>
Converts to this type from the input type.
impl<V, S> From<ReadSignal<V, S>> for TextProp
impl<V, S> From<ReadSignal<V, S>> for TextProp
fn from(s: ReadSignal<V, S>) -> TextProp
fn from(s: ReadSignal<V, S>) -> TextProp
Converts to this type from the input type.
impl<T> FromLocal<ArcReadSignal<T>> for ReadSignal<T, LocalStorage>where
T: 'static,
impl<T> FromLocal<ArcReadSignal<T>> for ReadSignal<T, LocalStorage>where
T: 'static,
fn from_local(value: ArcReadSignal<T>) -> ReadSignal<T, LocalStorage>
fn from_local(value: ArcReadSignal<T>) -> ReadSignal<T, LocalStorage>
Converts between the types.
impl<T, S> Hash for ReadSignal<T, S>
impl<T, S> Hash for ReadSignal<T, S>
impl<V, S> InnerHtmlValue for ReadSignal<V, S>
impl<V, S> InnerHtmlValue for ReadSignal<V, S>
type AsyncOutput = ReadSignal<V, S>
type AsyncOutput = ReadSignal<V, S>
The type after all async data have resolved.
type State = RenderEffect<<V as InnerHtmlValue>::State>
type State = RenderEffect<<V as InnerHtmlValue>::State>
The view state retained between building and rebuilding.
type Cloneable = ReadSignal<V, S>
type Cloneable = ReadSignal<V, S>
An equivalent value that can be cloned.
type CloneableOwned = ReadSignal<V, S>
type CloneableOwned = ReadSignal<V, S>
An equivalent value that can be cloned and is
'static.fn to_template(_buf: &mut String)
fn to_template(_buf: &mut String)
Renders the class to HTML for a
<template>.fn hydrate<const FROM_SERVER: bool>(
self,
el: &Element,
) -> <ReadSignal<V, S> as InnerHtmlValue>::State
fn hydrate<const FROM_SERVER: bool>( self, el: &Element, ) -> <ReadSignal<V, S> as InnerHtmlValue>::State
Adds interactivity as necessary, given DOM nodes that were created from HTML that has
either been rendered on the server, or cloned for a
<template>.fn build(self, el: &Element) -> <ReadSignal<V, S> as InnerHtmlValue>::State
fn build(self, el: &Element) -> <ReadSignal<V, S> as InnerHtmlValue>::State
Adds this class to the element during client-side rendering.
fn rebuild(self, state: &mut <ReadSignal<V, S> as InnerHtmlValue>::State)
fn rebuild(self, state: &mut <ReadSignal<V, S> as InnerHtmlValue>::State)
Updates the value.
fn into_cloneable(self) -> <ReadSignal<V, S> as InnerHtmlValue>::Cloneable
fn into_cloneable(self) -> <ReadSignal<V, S> as InnerHtmlValue>::Cloneable
Converts this to a cloneable type.
fn into_cloneable_owned(
self,
) -> <ReadSignal<V, S> as InnerHtmlValue>::CloneableOwned
fn into_cloneable_owned( self, ) -> <ReadSignal<V, S> as InnerHtmlValue>::CloneableOwned
Converts this to a cloneable, owned type.
fn dry_resolve(&mut self)
fn dry_resolve(&mut self)
โRunsโ the attribute without other side effects. For primitive types, this is a no-op. For
reactive types, this can be used to gather data about reactivity or about asynchronous data
that needs to be loaded.
async fn resolve(self) -> <ReadSignal<V, S> as InnerHtmlValue>::AsyncOutput
async fn resolve(self) -> <ReadSignal<V, S> as InnerHtmlValue>::AsyncOutput
โResolvesโ this into a type that is not waiting for any asynchronous data.
impl<V, S> IntoClass for ReadSignal<V, S>
impl<V, S> IntoClass for ReadSignal<V, S>
type AsyncOutput = ReadSignal<V, S>
type AsyncOutput = ReadSignal<V, S>
The type after all async data have resolved.
type State = RenderEffect<<V as IntoClass>::State>
type State = RenderEffect<<V as IntoClass>::State>
The view state retained between building and rebuilding.
type Cloneable = ReadSignal<V, S>
type Cloneable = ReadSignal<V, S>
An equivalent value that can be cloned.
type CloneableOwned = ReadSignal<V, S>
type CloneableOwned = ReadSignal<V, S>
An equivalent value that can be cloned and is
'static.fn hydrate<const FROM_SERVER: bool>(
self,
el: &Element,
) -> <ReadSignal<V, S> as IntoClass>::State
fn hydrate<const FROM_SERVER: bool>( self, el: &Element, ) -> <ReadSignal<V, S> as IntoClass>::State
Adds interactivity as necessary, given DOM nodes that were created from HTML that has
either been rendered on the server, or cloned for a
<template>.fn build(self, el: &Element) -> <ReadSignal<V, S> as IntoClass>::State
fn build(self, el: &Element) -> <ReadSignal<V, S> as IntoClass>::State
Adds this class to the element during client-side rendering.
fn rebuild(self, state: &mut <ReadSignal<V, S> as IntoClass>::State)
fn rebuild(self, state: &mut <ReadSignal<V, S> as IntoClass>::State)
Updates the value.
fn into_cloneable(self) -> <ReadSignal<V, S> as IntoClass>::Cloneable
fn into_cloneable(self) -> <ReadSignal<V, S> as IntoClass>::Cloneable
Converts this to a cloneable type.
fn into_cloneable_owned(self) -> <ReadSignal<V, S> as IntoClass>::CloneableOwned
fn into_cloneable_owned(self) -> <ReadSignal<V, S> as IntoClass>::CloneableOwned
Converts this to a cloneable, owned type.
fn dry_resolve(&mut self)
fn dry_resolve(&mut self)
โRunsโ the attribute without other side effects. For primitive types, this is a no-op. For
reactive types, this can be used to gather data about reactivity or about asynchronous data
that needs to be loaded.
async fn resolve(self) -> <ReadSignal<V, S> as IntoClass>::AsyncOutput
async fn resolve(self) -> <ReadSignal<V, S> as IntoClass>::AsyncOutput
โResolvesโ this into a type that is not waiting for any asynchronous data.
fn reset(state: &mut <ReadSignal<V, S> as IntoClass>::State)
fn reset(state: &mut <ReadSignal<V, S> as IntoClass>::State)
Reset the class list to the state before this class was added.
const MIN_LENGTH: usize = _
const MIN_LENGTH: usize = _
The minimum length of the HTML.
fn should_overwrite(&self) -> bool
fn should_overwrite(&self) -> bool
Whether this class attribute should overwrite previous class values.
Returns
true for class="..." attributes, false for class:name=value directives.fn to_template(class: &mut String)
fn to_template(class: &mut String)
Renders the class to HTML for a
<template>.impl<T, S> IntoInner for ReadSignal<T, S>where
S: Storage<ArcReadSignal<T>>,
impl<T, S> IntoInner for ReadSignal<T, S>where
S: Storage<ArcReadSignal<T>>,
fn into_inner(self) -> Option<<ReadSignal<T, S> as IntoInner>::Value>
fn into_inner(self) -> Option<<ReadSignal<T, S> as IntoInner>::Value>
Returns the inner value if this is the only reference to the signal.
Otherwise, returns
None and drops this reference. Read moreimpl<V, S> IntoProperty for ReadSignal<V, S>
impl<V, S> IntoProperty for ReadSignal<V, S>
type State = RenderEffect<<V as IntoProperty>::State>
type State = RenderEffect<<V as IntoProperty>::State>
The view state retained between building and rebuilding.
type Cloneable = ReadSignal<V, S>
type Cloneable = ReadSignal<V, S>
An equivalent value that can be cloned.
type CloneableOwned = ReadSignal<V, S>
type CloneableOwned = ReadSignal<V, S>
An equivalent value that can be cloned and is
'static.fn hydrate<const FROM_SERVER: bool>(
self,
el: &Element,
key: &str,
) -> <ReadSignal<V, S> as IntoProperty>::State
fn hydrate<const FROM_SERVER: bool>( self, el: &Element, key: &str, ) -> <ReadSignal<V, S> as IntoProperty>::State
Adds the property on an element created from HTML.
fn build(
self,
el: &Element,
key: &str,
) -> <ReadSignal<V, S> as IntoProperty>::State
fn build( self, el: &Element, key: &str, ) -> <ReadSignal<V, S> as IntoProperty>::State
Adds the property during client-side rendering.
fn rebuild(
self,
state: &mut <ReadSignal<V, S> as IntoProperty>::State,
key: &str,
)
fn rebuild( self, state: &mut <ReadSignal<V, S> as IntoProperty>::State, key: &str, )
Updates the property with a new value.
fn into_cloneable(self) -> <ReadSignal<V, S> as IntoProperty>::Cloneable
fn into_cloneable(self) -> <ReadSignal<V, S> as IntoProperty>::Cloneable
Converts this to a cloneable type.
fn into_cloneable_owned(
self,
) -> <ReadSignal<V, S> as IntoProperty>::CloneableOwned
fn into_cloneable_owned( self, ) -> <ReadSignal<V, S> as IntoProperty>::CloneableOwned
Converts this to a cloneable, owned type.
impl<V, S> IntoStyle for ReadSignal<V, S>
impl<V, S> IntoStyle for ReadSignal<V, S>
type AsyncOutput = ReadSignal<V, S>
type AsyncOutput = ReadSignal<V, S>
The type after all async data have resolved.
type State = RenderEffect<<V as IntoStyle>::State>
type State = RenderEffect<<V as IntoStyle>::State>
The view state retained between building and rebuilding.
type Cloneable = ReadSignal<V, S>
type Cloneable = ReadSignal<V, S>
An equivalent value that can be cloned.
type CloneableOwned = ReadSignal<V, S>
type CloneableOwned = ReadSignal<V, S>
An equivalent value that can be cloned and is
'static.fn hydrate<const FROM_SERVER: bool>(
self,
el: &Element,
) -> <ReadSignal<V, S> as IntoStyle>::State
fn hydrate<const FROM_SERVER: bool>( self, el: &Element, ) -> <ReadSignal<V, S> as IntoStyle>::State
Adds interactivity as necessary, given DOM nodes that were created from HTML that has
either been rendered on the server, or cloned for a
<template>.fn build(self, el: &Element) -> <ReadSignal<V, S> as IntoStyle>::State
fn build(self, el: &Element) -> <ReadSignal<V, S> as IntoStyle>::State
Adds this style to the element during client-side rendering.
fn rebuild(self, state: &mut <ReadSignal<V, S> as IntoStyle>::State)
fn rebuild(self, state: &mut <ReadSignal<V, S> as IntoStyle>::State)
Updates the value.
fn into_cloneable(self) -> <ReadSignal<V, S> as IntoStyle>::Cloneable
fn into_cloneable(self) -> <ReadSignal<V, S> as IntoStyle>::Cloneable
Converts this to a cloneable type.
fn into_cloneable_owned(self) -> <ReadSignal<V, S> as IntoStyle>::CloneableOwned
fn into_cloneable_owned(self) -> <ReadSignal<V, S> as IntoStyle>::CloneableOwned
Converts this to a cloneable, owned type.
fn dry_resolve(&mut self)
fn dry_resolve(&mut self)
โRunsโ the attribute without other side effects. For primitive types, this is a no-op. For
reactive types, this can be used to gather data about reactivity or about asynchronous data
that needs to be loaded.
async fn resolve(self) -> <ReadSignal<V, S> as IntoStyle>::AsyncOutput
async fn resolve(self) -> <ReadSignal<V, S> as IntoStyle>::AsyncOutput
โResolvesโ this into a type that is not waiting for any asynchronous data.
fn reset(state: &mut <ReadSignal<V, S> as IntoStyle>::State)
fn reset(state: &mut <ReadSignal<V, S> as IntoStyle>::State)
Reset the styling to the state before this style was added.
impl<V, S> IntoStyleValue for ReadSignal<V, S>
impl<V, S> IntoStyleValue for ReadSignal<V, S>
type AsyncOutput = ReadSignal<V, S>
type AsyncOutput = ReadSignal<V, S>
The type after all async data have resolved.
type State = (Arc<str>, RenderEffect<<V as IntoStyleValue>::State>)
type State = (Arc<str>, RenderEffect<<V as IntoStyleValue>::State>)
The view state retained between building and rebuilding.
type Cloneable = ReadSignal<V, S>
type Cloneable = ReadSignal<V, S>
An equivalent value that can be cloned.
type CloneableOwned = ReadSignal<V, S>
type CloneableOwned = ReadSignal<V, S>
An equivalent value that can be cloned and is
'static.fn build(
self,
style: &CssStyleDeclaration,
name: &str,
) -> <ReadSignal<V, S> as IntoStyleValue>::State
fn build( self, style: &CssStyleDeclaration, name: &str, ) -> <ReadSignal<V, S> as IntoStyleValue>::State
Adds this style to the element during client-side rendering.
fn rebuild(
self,
style: &CssStyleDeclaration,
name: &str,
state: &mut <ReadSignal<V, S> as IntoStyleValue>::State,
)
fn rebuild( self, style: &CssStyleDeclaration, name: &str, state: &mut <ReadSignal<V, S> as IntoStyleValue>::State, )
Updates the value.
fn hydrate(
self,
style: &CssStyleDeclaration,
name: &str,
) -> <ReadSignal<V, S> as IntoStyleValue>::State
fn hydrate( self, style: &CssStyleDeclaration, name: &str, ) -> <ReadSignal<V, S> as IntoStyleValue>::State
Adds interactivity as necessary, given DOM nodes that were created from HTML that has
either been rendered on the server, or cloned for a
<template>.fn into_cloneable(self) -> <ReadSignal<V, S> as IntoStyleValue>::Cloneable
fn into_cloneable(self) -> <ReadSignal<V, S> as IntoStyleValue>::Cloneable
Converts this to a cloneable type.
fn into_cloneable_owned(
self,
) -> <ReadSignal<V, S> as IntoStyleValue>::CloneableOwned
fn into_cloneable_owned( self, ) -> <ReadSignal<V, S> as IntoStyleValue>::CloneableOwned
Converts this to a cloneable, owned type.
fn dry_resolve(&mut self)
fn dry_resolve(&mut self)
โRunsโ the attribute without other side effects. For primitive types, this is a no-op. For
reactive types, this can be used to gather data about reactivity or about asynchronous data
that needs to be loaded.
async fn resolve(self) -> <ReadSignal<V, S> as IntoStyleValue>::AsyncOutput
async fn resolve(self) -> <ReadSignal<V, S> as IntoStyleValue>::AsyncOutput
โResolvesโ this into a type that is not waiting for any asynchronous data.
impl<T, S> IsDisposed for ReadSignal<T, S>
impl<T, S> IsDisposed for ReadSignal<T, S>
fn is_disposed(&self) -> bool
fn is_disposed(&self) -> bool
If
true, the signal cannot be accessed without a panic.impl<T, S> PartialEq for ReadSignal<T, S>
impl<T, S> PartialEq for ReadSignal<T, S>
impl<T, S> ReadUntracked for ReadSignal<T, S>where
T: 'static,
S: Storage<ArcReadSignal<T>>,
impl<T, S> ReadUntracked for ReadSignal<T, S>where
T: 'static,
S: Storage<ArcReadSignal<T>>,
type Value = ReadGuard<T, Plain<T>>
type Value = ReadGuard<T, Plain<T>>
The guard type that will be returned, which can be dereferenced to the value.
fn try_read_untracked(
&self,
) -> Option<<ReadSignal<T, S> as ReadUntracked>::Value>
fn try_read_untracked( &self, ) -> Option<<ReadSignal<T, S> as ReadUntracked>::Value>
Returns the guard, or
None if the signal has already been disposed.fn read_untracked(&self) -> Self::Value
fn read_untracked(&self) -> Self::Value
Returns the guard. Read more
fn custom_try_read(&self) -> Option<Option<Self::Value>>
fn custom_try_read(&self) -> Option<Option<Self::Value>>
This is a backdoor to allow overriding the
Read::try_read implementation despite it being auto implemented. Read moreimpl<V, S> Render for ReadSignal<V, S>
impl<V, S> Render for ReadSignal<V, S>
type State = RenderEffectState<<V as Render>::State>
type State = RenderEffectState<<V as Render>::State>
The โview stateโ for this type, which can be retained between updates. Read more
fn build(self) -> <ReadSignal<V, S> as Render>::State
fn build(self) -> <ReadSignal<V, S> as Render>::State
Creates the view for the first time, without hydrating from existing HTML.
fn rebuild(self, state: &mut <ReadSignal<V, S> as Render>::State)
fn rebuild(self, state: &mut <ReadSignal<V, S> as Render>::State)
Updates the view with new data.
impl<V, S> RenderHtml for ReadSignal<V, S>
impl<V, S> RenderHtml for ReadSignal<V, S>
const MIN_LENGTH: usize = 0usize
const MIN_LENGTH: usize = 0usize
The minimum length of HTML created when this view is rendered.
type AsyncOutput = ReadSignal<V, S>
type AsyncOutput = ReadSignal<V, S>
The type of the view after waiting for all asynchronous data to load.
type Owned = ReadSignal<V, S>
type Owned = ReadSignal<V, S>
An equivalent value that is
'static.fn dry_resolve(&mut self)
fn dry_resolve(&mut self)
โRunsโ the view without other side effects. For primitive types, this is a no-op. For
reactive types, this can be used to gather data about reactivity or about asynchronous data
that needs to be loaded.
async fn resolve(self) -> <ReadSignal<V, S> as RenderHtml>::AsyncOutput
async fn resolve(self) -> <ReadSignal<V, S> as RenderHtml>::AsyncOutput
Waits for any asynchronous sections of the view to load and returns the output.
fn to_html_with_buf(
self,
buf: &mut String,
position: &mut Position,
escape: bool,
mark_branches: bool,
extra_attrs: Vec<AnyAttribute>,
)
fn to_html_with_buf( self, buf: &mut String, position: &mut Position, escape: bool, mark_branches: bool, extra_attrs: Vec<AnyAttribute>, )
Renders a view to HTML, writing it into the given buffer.
fn to_html_async_with_buf<const OUT_OF_ORDER: bool>(
self,
buf: &mut StreamBuilder,
position: &mut Position,
escape: bool,
mark_branches: bool,
extra_attrs: Vec<AnyAttribute>,
)where
ReadSignal<V, S>: Sized,
fn to_html_async_with_buf<const OUT_OF_ORDER: bool>(
self,
buf: &mut StreamBuilder,
position: &mut Position,
escape: bool,
mark_branches: bool,
extra_attrs: Vec<AnyAttribute>,
)where
ReadSignal<V, S>: Sized,
Renders a view into a buffer of (synchronous or asynchronous) HTML chunks.
fn hydrate<const FROM_SERVER: bool>(
self,
cursor: &Cursor,
position: &PositionState,
) -> <ReadSignal<V, S> as Render>::State
fn hydrate<const FROM_SERVER: bool>( self, cursor: &Cursor, position: &PositionState, ) -> <ReadSignal<V, S> as Render>::State
Makes a set of DOM nodes rendered from HTML interactive. Read more
fn into_owned(self) -> <ReadSignal<V, S> as RenderHtml>::Owned
fn into_owned(self) -> <ReadSignal<V, S> as RenderHtml>::Owned
Convert into the equivalent value that is
'static.const EXISTS: bool = true
const EXISTS: bool = true
Whether this should actually exist in the DOM, if it is the child of an element.
fn to_html_branching(self) -> Stringwhere
Self: Sized,
fn to_html_branching(self) -> Stringwhere
Self: Sized,
Renders a view to HTML with branch markers. This can be used to support libraries that diff
HTML pages against one another, by marking sections of the view that branch to different
types with marker comments.
fn to_html_stream_in_order(self) -> StreamBuilderwhere
Self: Sized,
fn to_html_stream_in_order(self) -> StreamBuilderwhere
Self: Sized,
Renders a view to an in-order stream of HTML.
fn to_html_stream_in_order_branching(self) -> StreamBuilderwhere
Self: Sized,
fn to_html_stream_in_order_branching(self) -> StreamBuilderwhere
Self: Sized,
Renders a view to an in-order stream of HTML with branch markers. This can be used to support libraries that diff
HTML pages against one another, by marking sections of the view that branch to different
types with marker comments.
fn to_html_stream_out_of_order(self) -> StreamBuilderwhere
Self: Sized,
fn to_html_stream_out_of_order(self) -> StreamBuilderwhere
Self: Sized,
Renders a view to an out-of-order stream of HTML.
fn to_html_stream_out_of_order_branching(self) -> StreamBuilderwhere
Self: Sized,
fn to_html_stream_out_of_order_branching(self) -> StreamBuilderwhere
Self: Sized,
Renders a view to an out-of-order stream of HTML with branch markers. This can be used to support libraries that diff
HTML pages against one another, by marking sections of the view that branch to different
types with marker comments.
fn hydrate_async(
self,
cursor: &Cursor,
position: &PositionState,
) -> impl Future<Output = Self::State>
fn hydrate_async( self, cursor: &Cursor, position: &PositionState, ) -> impl Future<Output = Self::State>
Asynchronously makes a set of DOM nodes rendered from HTML interactive. Read more
fn hydrate_from<const FROM_SERVER: bool>(self, el: &Element) -> Self::Statewhere
Self: Sized,
fn hydrate_from<const FROM_SERVER: bool>(self, el: &Element) -> Self::Statewhere
Self: Sized,
Hydrates using
RenderHtml::hydrate, beginning at the given element.fn hydrate_from_position<const FROM_SERVER: bool>(
self,
el: &Element,
position: Position,
) -> Self::Statewhere
Self: Sized,
fn hydrate_from_position<const FROM_SERVER: bool>(
self,
el: &Element,
position: Position,
) -> Self::Statewhere
Self: Sized,
Hydrates using
RenderHtml::hydrate, beginning at the given element and position.impl<T, St> Serialize for ReadSignal<T, St>
impl<T, St> Serialize for ReadSignal<T, St>
fn serialize<S>(
&self,
serializer: S,
) -> Result<<S as Serializer>::Ok, <S as Serializer>::Error>where
S: Serializer,
fn serialize<S>(
&self,
serializer: S,
) -> Result<<S as Serializer>::Ok, <S as Serializer>::Error>where
S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl<T, S> Copy for ReadSignal<T, S>
impl<T, S> Eq for ReadSignal<T, S>