Struct SharedValue
pub struct SharedValue<T, Ser = JsonSerdeCodec> {
value: T,
ser: PhantomData<Ser>,
}Expand description
A smart pointer that allows you to share identical, synchronously-loaded data between the server and the client.
If this constructed on the server, it serializes its value into the shared context. If it is constructed on the client during hydration, it reads its value from the shared context. If it it constructed on the client at any other time, it simply runs on the client.
Fields
value: Tser: PhantomData<Ser>Implementations
pub fn into_inner(self) -> T
pub fn into_inner(self) -> T
Returns the inner value.
pub fn new(initial: impl FnOnce() -> T) -> SharedValue<T>
pub fn new(initial: impl FnOnce() -> T) -> SharedValue<T>
Wraps the initial value.
If this is on the server, the function will be invoked and the value serialized. When it runs on the client, it will be deserialized without running the function again.
This uses the JsonSerdeCodec encoding.
pub fn new_str(initial: impl FnOnce() -> T) -> SharedValue<T, FromToStringCodec>
pub fn new_str(initial: impl FnOnce() -> T) -> SharedValue<T, FromToStringCodec>
Wraps the initial value.
If this is on the server, the function will be invoked and the value serialized. When it runs on the client, it will be deserialized without running the function again.
This uses the FromToStringCodec encoding.
pub fn new_serde_lite(
initial: impl FnOnce() -> T,
) -> SharedValue<T, SerdeLite<JsonSerdeCodec>>
Available on crate feature serde-lite only.
pub fn new_serde_lite( initial: impl FnOnce() -> T, ) -> SharedValue<T, SerdeLite<JsonSerdeCodec>>
serde-lite only.Wraps the initial value.
If this is on the server, the function will be invoked and the value serialized. When it runs on the client, it will be deserialized without running the function again.
This uses the SerdeLite encoding.
pub fn new_with_encoding(initial: impl FnOnce() -> T) -> SharedValue<T, Ser>
pub fn new_with_encoding(initial: impl FnOnce() -> T) -> SharedValue<T, Ser>
Wraps the initial value.
If this is on the server, the function will be invoked and the value serialized. When it runs on the client, it will be deserialized without running the function again.
This uses Ser as an encoding.