Struct RenderEffect
pub struct RenderEffect<T>where
T: 'static,{
value: Arc<RwLock<Option<T>>>,
inner: Arc<RwLock<EffectInner>>,
}Expand description
A render effect is similar to an Effect, but with two key differences:
- Its first run takes place immediately and synchronously: for example, if it is being used to drive a user interface, it will run during rendering, not on the next tick after rendering. (Hence โrender effect.โ)
- It is canceled when the
RenderEffectitself is dropped, rather than being stored in the reactive system and canceled when theOwnercleans up.
Unless you are implementing a rendering framework, or require one of these two characteristics, it is unlikely you will use render effects directly.
Like an Effect, a render effect runs only with the effects feature
enabled.
Fields
value: Arc<RwLock<Option<T>>>inner: Arc<RwLock<EffectInner>>Implementations
impl<T> RenderEffect<T>where
T: 'static,
impl<T> RenderEffect<T>where
T: 'static,
pub fn new(fun: impl FnMut(Option<T>) -> T + 'static) -> RenderEffect<T>
pub fn new(fun: impl FnMut(Option<T>) -> T + 'static) -> RenderEffect<T>
Creates a new render effect, which immediately runs fun.
pub fn new_with_value(
fun: impl FnMut(Option<T>) -> T + 'static,
initial_value: Option<T>,
) -> RenderEffect<T>
pub fn new_with_value( fun: impl FnMut(Option<T>) -> T + 'static, initial_value: Option<T>, ) -> RenderEffect<T>
Creates a new render effect with an initial value.
pub async fn new_with_async_value(
fun: impl FnMut(Option<T>) -> T + 'static,
value: impl IntoFuture<Output = T> + 'static,
) -> RenderEffect<T>
pub async fn new_with_async_value( fun: impl FnMut(Option<T>) -> T + 'static, value: impl IntoFuture<Output = T> + 'static, ) -> RenderEffect<T>
Creates a new render effect, which immediately runs fun.
pub fn with_value_mut<U>(&self, fun: impl FnOnce(&mut T) -> U) -> Option<U>
pub fn with_value_mut<U>(&self, fun: impl FnOnce(&mut T) -> U) -> Option<U>
Mutably accesses the current value.
pub fn take_value(&self) -> Option<T>
pub fn take_value(&self) -> Option<T>
Takes the current value, replacing it with None.
impl<T> RenderEffect<T>
impl<T> RenderEffect<T>
pub fn new_isomorphic(
fun: impl FnMut(Option<T>) -> T + Send + Sync + 'static,
) -> RenderEffect<T>
pub fn new_isomorphic( fun: impl FnMut(Option<T>) -> T + Send + Sync + 'static, ) -> RenderEffect<T>
Creates a render effect that will run whether the effects feature is enabled or not.